""" Automated cron scheduler for daily submissions """
import os
import sysconfig
import sys
import logging
from datetime import datetime
from crontab import CronTab

TP_BIN = "tp-timesheet"
SYS_PATH = os.environ.get("PATH")

logger = logging.getLogger(__name__)


class ScheduleForm:
    """Cron Schedule Handler"""

    def __init__(self):
        self.executable = self.find_executable_location()

    @staticmethod
    def find_executable_location():
        """
        Search and locate the TP_BIN executable that was installed by pip
        Unfortunately pip does not install in a predictable manner or have a mechanism to get the location
        """
        # Check if this is running in a conda env
        sysconfig_scripts_path = sysconfig.get_path("scripts")
        if "conda" in sysconfig_scripts_path:
            bins = os.listdir(sysconfig_scripts_path)
            if TP_BIN in bins:
                return os.path.join(sysconfig_scripts_path, TP_BIN)
            raise ValueError(
                f"It appears you are running in a conda env but the {TP_BIN} binary \
cannot be found in: {sysconfig_scripts_path}"
            )

        # Check prefix path (should work on *NIX, not later MacOS though)
        prefix_bin_path = os.path.join(sys.prefix, "bin")
        if TP_BIN in os.listdir(prefix_bin_path):
            return os.path.join(prefix_bin_path, TP_BIN)

        # Search path relative to this file
        current_file_path = os.path.abspath(__file__)
        python_scripts_path = None
        if "lib" in current_file_path:
            python_scripts_path = os.path.join(
                current_file_path.split("/lib/")[0], "bin"
            )
            if TP_BIN in os.listdir(python_scripts_path):
                return os.path.join(python_scripts_path, TP_BIN)

        raise ValueError(
            f"Could not find the '{TP_BIN}' executable, searched: ",
            [sysconfig_scripts_path, prefix_bin_path, python_scripts_path],
        )

    def schedule(self):
        """Create the crontab schedule"""
        with CronTab(user=True) as cron:
            job = cron.new(
                command=f"PATH='{SYS_PATH}' {self.executable} --start today --count 1 --notification"
            )
            job.minute.parse(30)
            job.hour.parse(9)
            job.dow.parse("MON-FRI")
            assert job.is_valid()
            cron_schedule = job.schedule(date_from=datetime.now())
        logger.info(
            "Job has been scheduled in your crontab, the next scheduled run will be on %s.",
            cron_schedule.get_next(),
        )
        logger.info("Run `crontab -l` to see your scheduled tasks.")
        logger.info("Run `crontab -r` to clear all scheduled tasks.")


if __name__ == "__main__":
    # Executable for debugging purposes
    schedule = ScheduleForm()
    schedule.schedule()



""" Module containing tool to submit the form """
import logging
import os
import datetime
from selenium import webdriver
from selenium.webdriver.common.by import By
from PIL import Image

logger = logging.getLogger(__name__)

DESKTOP_PATH = os.path.join(os.path.join(os.path.expanduser("~")), "Desktop")


def submit_timesheet(url, email, date, verbose=False, dry_run=False, working_hours=8):
    """submit tp timesheet through selenium webdriver"""
    if not isinstance(date, datetime.date):
        raise TypeError(
            f"Date must be of type <datetime.date>, got {date}, of type: {type(date)}"
        )

    options = webdriver.ChromeOptions()
    options.add_argument("--ignore-ssl-errors=yes")
    options.add_argument("--ignore-certificate-errors")

    with webdriver.Remote(
        command_executor="http://localhost:4444/wd/hub", options=options
    ) as browser:

        # use browser to access desired webpage
        browser.get(url)
        browser.maximize_window()
        # wait a bit for elements on webpage to fully load
        browser.implicitly_wait(5)

        # find the email field element and fill your email
        email_field = browser.find_element(
            By.XPATH,
            "(//input)[1]",
        )
        email_field.send_keys(email)

        # find the date field and fill date
        date_field = browser.find_element(
            By.XPATH,
            "(//input)[2]",
        )
        date_field.send_keys(date.strftime("%m/%d/%Y"))

        if verbose:
            # Capture image of top half of submission
            image_path = os.path.join(
                DESKTOP_PATH, f"timesheet_top_{date.strftime('%d_%m_%Y')}.png"
            )
            logger.info("Saving top of timesheet to: %s", image_path)
            browser.save_screenshot(image_path)
            image = Image.open(image_path)
            image.show()

        # find and fill in live hours
        live_hours = browser.find_element(
            By.XPATH,
            "(//input)[3]",
        )
        live_hours.send_keys(working_hours)

        # find and fill in the rest of the hours
        idle_hours = browser.find_element(
            By.XPATH,
            "(//input)[4]",
        )
        idle_hours.send_keys("0")
        training_hours = browser.find_element(
            By.XPATH,
            "(//input)[5]",
        )
        training_hours.send_keys("0")
        tool_issues = browser.find_element(
            By.XPATH,
            "(//input)[6]",
        )
        tool_issues.send_keys("0")

        if not dry_run:
            # find submit button and click submit
            submit = browser.find_element(
                By.XPATH,
                "(//button)[2]/div[1]",
            )
            submit.click()
        browser.implicitly_wait(5)

        if verbose:
            # Capture image of top half of submission
            image_path = os.path.join(
                DESKTOP_PATH, f"timesheet_bottom_{date.strftime('%d_%m_%Y')}.png"
            )
            logger.info("Saving bottom of timesheet to: %s", image_path)
            browser.save_screenshot(image_path)
            image = Image.open(image_path)
            image.show()



""" Handler for running selenium and chrome backend """
import os
import sys
import platform
import subprocess
import logging
import time
import http
import urllib
import urllib3
import docker
from selenium import webdriver

ARM_IMAGE = "seleniarm/standalone-chromium:105.0"
X86_IMAGE = "selenium/standalone-chrome:105.0"

logger = logging.getLogger(__name__)


class DockerHandlerException(Exception):
    """Exceptions for DockerHandler class"""


class DockerHandler:
    """Docker handler"""

    def __init__(self):
        self.client = docker.from_env()
        self.arch = platform.machine()
        self.image = self.select_image(self.arch)
        self.container = None

    @staticmethod
    def select_image(arch):
        """Select the correct image based on the client architecture"""
        if arch == "arm64":
            return ARM_IMAGE
        return X86_IMAGE

    def pull_image(self):
        """Pull the selenium image"""
        self.client.images.pull(self.image)

    def run_container(self):
        """Run the selenium image in a container"""
        self.container = self.client.containers.run(
            self.image,
            auto_remove=True,
            detach=True,
            shm_size="2g",
            ports={"4444/tcp": 4444},
        )

        # Ensure selenium api is responsive
        for i in range(5):
            try:
                with urllib.request.urlopen("http://localhost:4444/") as page:
                    if page.getcode() == 200:
                        break
            except (http.client.RemoteDisconnected, urllib.error.URLError):
                pass
            if i == 4:
                raise RuntimeError(
                    "Selenium Docker API did not return a 200 code within 5 seconds"
                )
            time.sleep(1)

        # Ensure chrome driver is responsive
        options = webdriver.ChromeOptions()
        options.add_argument("--ignore-ssl-errors=yes")
        options.add_argument("--ignore-certificate-errors")
        for i in range(10):
            try:
                with webdriver.Remote(
                    command_executor="http://localhost:4444/wd/hub", options=options
                ) as _:
                    break
            except urllib3.exceptions.ProtocolError:
                pass
            if i == 4:
                raise RuntimeError("Chrome Docker API did not respond within 5 seconds")
            time.sleep(1)

    def rm_container(self):
        """Remove the container"""
        self.container.remove(force=True)

    @staticmethod
    def install_and_launch_docker():
        """Static method to ensure docker is installed and running.
        If not then it will attempt to rectify the problems
        """
        # Check docker is installed
        try:
            subprocess.run(["docker", "--version"], check=True, capture_output=True)
        except FileNotFoundError as exc:
            logger.info(
                "Docker is not installed properly on your system. Attempting to install with brew"
            )
            # Check brew is installed
            brew_version = subprocess.run(
                ["brew", "--version"], check=True, capture_output=True
            )
            if brew_version.returncode != 0:
                notification_text = (
                    "Brew is not installed, so docker cannot be installed automatically. "
                    "Consider installing https://brew.sh/ or go to docker website to download "
                    "https://docs.docker.com/desktop/install/mac-install/"
                )
                logger.warning(notification_text)
                os.system(
                    f"""osascript -e 'display dialog "{notification_text}" with title "TP Timesheet" buttons "OK" \
                            default button "OK" with icon 2'"""
                )
                raise DockerHandlerException(notification_text) from exc
            user_confirm = input(
                "\nDocker is not installed.\n"
                "Would you like to attempt to install docker using brew? [y/N]:"
            )
            if user_confirm.lower() != "y":
                raise DockerHandlerException(
                    "Docker installation aborted by user"
                ) from exc
            logger.info("Installing docker with brew")
            subprocess.run(
                ["brew", "install", "--cask", "docker"],
                check=True,
                capture_output=False,
            )
            # Unfortunately docker needs to be launched from finder first time to finish the setup
            notification_text = (
                "Docker was installed with brew. To finish the docker setup, "
                "run the docker application from within your Applications folder (will open automatically)"
            )
            os.system(
                f"""osascript -e 'display dialog "{notification_text}" with title "TP Timesheet" buttons "OK" \
                        default button "OK" with icon 2'"""
            )
            os.system("open /Applications")
            sys.exit(0)

        # Launch docker engine, does nothing if already running
        docker_open = subprocess.run(
            ["open", "--hide", "--background", "-a", "Docker"],
            check=False,
            capture_output=True,
        )
        if docker_open.returncode != 0:
            # Something unexpected happened. Capture stderror
            raise DockerHandlerException(docker_open.stderr.decode().strip())

        # Check docker engine is running. Timeout after 30 seconds
        for _ in range(15):
            docker_stats = subprocess.run(
                ["docker", "stats", "--no-stream"], check=False, capture_output=True
            )
            if docker_stats.returncode == 0:
                return
            logger.debug("Waiting for docker engine to spool up")
            time.sleep(2)

        # Docker engine timed out
        raise DockerHandlerException(
            "Docker engine is unresponsive. Please check your docker install"
        )



""" Module containing methods to process `date` related """
import re
from typing import List, Tuple
import datetime
from datetime import datetime, timedelta
import dateutil.parser
from tp_timesheet.config import Config


def get_working_dates(
    start: datetime.date, count: int, cal, working_hours: int
) -> List[Tuple[datetime.date, int]]:
    """get workdays from `start` date to `start+count` date"""
    working_dates = []
    for i in range(count):
        current_date = start + timedelta(days=i)
        year = current_date.year
        holidays = cal.holidays(year)
        holidates = [date for (date, _) in holidays]
        if current_date.isoweekday() < 6:
            if current_date not in holidates:
                working_dates.append((current_date, working_hours))
            else:
                working_dates.append((current_date, 0))  # 0: number of working hours
    return working_dates


def get_start_date(start_date_arg: str) -> datetime.date:
    """parse user's `start` argument"""
    if start_date_arg.lower() == "today":
        start_date = datetime.today().date()
    elif start_date_arg.lower() == "yesterday":
        start_date = datetime.today().date() - timedelta(days=1)
    else:
        # PR#22 Parsing Dates with dateutil
        numbers = re.split("[-/ ]", start_date_arg)
        # 4 Digit Year
        if max(map(len, numbers)) == 4:
            yearfirst = len(numbers[0]) == 4
            dayfirst = not yearfirst
            start_date = dateutil.parser.parse(
                start_date_arg, yearfirst=yearfirst, dayfirst=dayfirst
            ).date()
        # 2 Digit Year
        else:
            cand1 = dateutil.parser.parse(start_date_arg, dayfirst=True).date()  # DMY
            cand2 = dateutil.parser.parse(start_date_arg, yearfirst=True).date()  # YMD
            today = datetime.today().date()
            diff1 = abs((cand1 - today).total_seconds())
            diff2 = abs((cand2 - today).total_seconds())
            # Select Nearest
            if diff1 < diff2:
                start_date = cand1
            else:
                start_date = cand2
    return start_date


def assert_start_date(start_date: datetime.date) -> bool:
    """
    check the start date submitting is bounded within `n` days.
    parse `n` from config file. default : 7

    Returns:
        True: when date is ok or verified by user as ok
        False: when date is invalid and confirmed by user as invalid
    """
    start_date_str = start_date.strftime("%d/%m/%Y")
    today = datetime.today().date()
    if (
        Config.SANITY_CHECK_START_DATE
        and int(Config.SANITY_CHECK_RANGE) < abs(today - start_date).days
    ):
        user_confirm = input(
            f"The entered date '{start_date_str}' "
            f"is beyond the maximum '{Config.SANITY_CHECK_RANGE}' day window from today.\n"
            f"You can modify the threshold and/or disable this confirmation option from '{Config.CONFIG_PATH}'.\n"
            f" - To modify threshold, change value of '{next(iter(Config.sanity_check_range_dict))}'.\n"
            f" - To disable, pass 'False' to '{next(iter(Config.sanity_check_bool_dict))}'.\n"
            f"Do you want to submit the timesheet anyway? [y/N]: "
        )
        if user_confirm.lower() != "y":
            return False
    return True



""" Entry point for cli """
import logging
import os
import sys
import argparse
import warnings
import selenium
import docker
from workalendar.asia import Singapore
from tp_timesheet.docker_handler import DockerHandler, DockerHandlerException
from tp_timesheet.submit_form import submit_timesheet
from tp_timesheet.date_utils import get_working_dates, get_start_date, assert_start_date
from tp_timesheet.schedule import ScheduleForm
from tp_timesheet.config import Config

logger = logging.getLogger(__name__)


def parse_args():
    """Parse arguments from the command line"""
    parser = argparse.ArgumentParser(
        description="TP Automated Timesheet Submission - CLI Tool"
    )
    group = parser.add_mutually_exclusive_group(required=True)
    group.add_argument(
        "-s",
        "--start",
        type=str,
        help="Normal mode: Indicating first date to submit a timesheet. \
                Accepted arguments = ['Day/Month/Year', 'Day/Month/Year', today, yesterday]. \
                NOTE: 'Month/Day/Year' is not accepted!",
    )
    group.add_argument(
        "-a",
        "--automate",
        type=str,
        help="Automate mode: Schedules the form submission to run automatically. Accepted arguments = [weekdays]",
    )
    parser.add_argument(
        "-c",
        "--count",
        type=int,
        required=False,
        default=1,
        help="Number of weekdays to submit a timesheet for, use '5' on a monday to submit for the entire week",
    )
    parser.add_argument(
        "--hours",
        type=int,
        default=8,
        help="Number of hours to submit. Default=8",
    )
    parser.add_argument(
        "-n",
        "--notification",
        action="store_true",
        help="Notification feature, notification will be shown when the timesheet submission is done(for OSX only)",
    )
    parser.add_argument(
        "-v",
        "--verbose",
        action="store_true",
        help="Verbose mode, prints logs and saves screenshots of the timesheet submission page to your desktop",
    )
    parser.add_argument(
        "-d",
        "--dry-run",
        action="store_true",
        help="Dry run mode, runs through as per normal but will not click submit",
    )
    return parser.parse_args()


def run():
    """Entry point"""
    # pylint: disable=too-many-statements
    args = parse_args()
    notification_text = None
    docker_handler = None
    notification_flag = False

    config = Config(verbose=args.verbose)

    try:
        DockerHandler.install_and_launch_docker()

        # Automate Mode
        if args.automate is not None:
            valid_options = ["weekdays"]
            if args.automate not in valid_options:
                logger.error(
                    "'%s' is not a valid option for --automate mode", args.automate
                )
                return
            scheduler = ScheduleForm()
            scheduler.schedule()
            return

        # Normal Mode
        if not args.verbose:
            warnings.filterwarnings(
                "ignore", message="Please take note that, due to arbitrary decisions, "
            )
        cal = Singapore()

        start_date = get_start_date(args.start)
        if not assert_start_date(start_date):
            logger.critical("Start date failed sanity check. Aborting program")
            sys.exit(1)
        dates = get_working_dates(
            start=start_date, count=args.count, cal=cal, working_hours=args.hours
        )

        if not dates:
            logger.info(
                "Submitted dates fall on weekends, form submission is not required."
            )
            return

        string_list = [f"{date}: {hours} hours" for (date, hours) in dates]
        logger.info(
            "Date(s) (yyyy-mm-dd) to be submitted for %s: %s", config.EMAIL, string_list
        )

        docker_handler = DockerHandler()
        logger.debug("Pulling latest image")
        docker_handler.pull_image()
        logger.debug("Launching docker container for selenium backend")
        docker_handler.run_container()

        for (date, hours) in dates:
            submit_timesheet(
                config.URL,
                config.EMAIL,
                date,
                verbose=args.verbose,
                dry_run=args.dry_run,
                working_hours=hours,
            )

        # Notification (OSX only)
        if args.notification and sys.platform.lower() == "darwin":
            if len(dates) == 1:
                notification_text = (
                    f"Timesheet for {args.start.lower()} is successfully submitted."
                )
            else:
                notification_text = f"Timesheets from {dates[0]} to {dates[-1]} are successfully submitted."
            if args.dry_run:
                notification_text = f"[DRY_RUN] {notification_text}"
            os.system(
                f"""osascript -e 'display notification "{notification_text}" with title "TP Timesheet"'"""
            )
    except docker.errors.DockerException:
        notification_text = (
            "⚠️ TP-timesheet was not submitted successfully. Check if Docker is running"
        )
        logger.critical(notification_text, exc_info=True)
        os.system(
            f"""osascript -e 'display dialog "{notification_text}" with title "TP Timesheet" buttons "OK" \
                    default button "OK" with icon 2'"""
        )
    except selenium.common.exceptions.NoSuchElementException:
        notification_text = "⚠️ TP-timesheet was not submitted successfully. An element on the url \
was not found by Selenium"
        logger.critical(notification_text, exc_info=True)
        os.system(
            f"""osascript -e 'display dialog "{notification_text}" with title "TP Timesheet" buttons "OK" \
                    default button "OK" with icon 2'"""
        )
        notification_flag = True
    except DockerHandlerException as error:
        notification_text = f"⚠️ TP-timesheet was not submitted successfully. {error}"
        logger.critical(notification_text, exc_info=True)
        os.system(
            f"""osascript -e 'display dialog "{notification_text}" with title "TP Timesheet" buttons "OK" \
                    default button "OK" with icon 2'"""
        )
        notification_flag = True
    except Exception:  # pylint: disable=broad-except
        notification_text = "⚠️ TP Timesheet was not submitted successfully."
        logger.critical(notification_text, exc_info=True)
        os.system(
            f"""osascript -e 'display dialog "{notification_text}" with title "TP Timesheet" buttons "OK" \
                    default button "OK" with icon 2'"""
        )
        notification_flag = True
    finally:
        try:
            logger.debug("Cleaning up docker container")
            if docker_handler is not None:
                docker_handler.rm_container()
        except Exception:  # pylint: disable=broad-except
            notification_text = "Ran into an unexpected error while attempting to clean up docker container"
            logger.critical(notification_text, exc_info=True)
            if not notification_flag:
                # Don't show two notifications sequentially
                os.system(
                    f"""osascript -e 'display dialog "{notification_text}" with title "TP Timesheet" buttons "OK" \
                        default button "OK" with icon 2'"""
                )


if __name__ == "__main__":
    run()



"""Module to store, create or read from a configuration file and parse the values and variables to
globals for other modules to access.
"""
import logging
import logging.handlers
import os
import re
import configparser
from pathlib import Path

logger = logging.getLogger(__name__)


class Config:
    """Config class, manages the initialization of all the necesarry globals."""

    # pylint:disable = anomalous-backslash-in-string
    ROOT_LOGGER = None
    CONFIG_DIR = Path.home().joinpath(".config", "tp-timesheet")
    CONFIG_DIR.mkdir(parents=True, exist_ok=True)
    LOG_DIR = Path.joinpath(CONFIG_DIR, "logs")
    LOG_DIR.mkdir(exist_ok=True)
    LOG_PATH = LOG_DIR.joinpath("tp.logs")

    # config parameters (need to be accessible to tests without invoking __init__)
    sanity_check_bool_dict = {"sanity_check_start_date": "True"}
    sanity_check_range_dict = {"sanity_check_range": "7"}
    DEFAULT_CONF = {**sanity_check_bool_dict, **sanity_check_range_dict}

    @classmethod
    def __init__(cls, verbose=False, config_filename="tp.conf"):
        """This is the entry point for the class and running this will setup the tp-timesheet
        config and make all the necesarry globals available
        """
        cls.VERBOSE = verbose
        cls.CONFIG_DIR = Config.CONFIG_DIR
        cls.CONFIG_PATH = cls.CONFIG_DIR.joinpath(config_filename)

        # Initialize root logger
        cls.init_logger()

        # Read from config file
        config = cls._read_write_config()

        # Load global configurations
        cls.EMAIL = config.get("configuration", "tp_email")
        cls.URL = config.get("configuration", "tp_url")
        cls.SANITY_CHECK_START_DATE = config.get(
            "configuration", next(iter(cls.sanity_check_bool_dict))
        )
        cls.SANITY_CHECK_RANGE = config.get(
            "configuration", next(iter(cls.sanity_check_range_dict))
        )

    @classmethod
    def init_logger(cls):
        """Initialze root logger."""

        # create root logger
        cls.ROOT_LOGGER.setLevel(logging.DEBUG)

        # create formatter
        log_format = logging.Formatter(
            "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
        )

        # log to stdout
        level = logging.DEBUG if cls.VERBOSE else logging.INFO
        stream_handler = logging.StreamHandler()
        stream_handler.setLevel(level)
        stream_handler.setFormatter(log_format)
        cls.ROOT_LOGGER.addHandler(stream_handler)

        # log to file, rotate every 4 weeks, save up to 8 weeks
        file_handler = logging.handlers.TimedRotatingFileHandler(
            Config.LOG_PATH, when="W6", interval=4, backupCount=8
        )
        file_handler.setLevel(logging.DEBUG)
        file_handler.setFormatter(log_format)
        cls.ROOT_LOGGER.addHandler(file_handler)

    @staticmethod
    def is_valid_email(email):
        """Check email is valid"""
        return re.search(r"^[a-z0-9]+[\._]?[a-z0-9]+[@]\w+[.]\w{2,3}$", email)

    @staticmethod
    def is_valid_url(url):
        """Check url is valid"""
        regex = re.compile(
            r"^https://forms\."  # knowns start to url
            r"(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+[A-Z]{2,6}\.?)"  # domain
            r"(?:/?|[/?]\S+)$",
            re.IGNORECASE,
        )
        return bool(regex.search(url))

    @classmethod
    def _read_write_config(cls):
        """Function to read the config file or create one if it doesn't exist"""
        config = configparser.ConfigParser(allow_no_value=True)
        # Write config template to file if it doesn't already exist
        if not os.path.exists(cls.CONFIG_PATH):
            logger.info(
                "No config file was found, creating one at: %s", cls.CONFIG_PATH
            )
            # Gather input from user to populate the config
            email = input("Enter TP email:")
            while not cls.is_valid_email(email):
                email = input("Invalid email, please try again:")
            url = input("Enter timesheet url:")
            while not cls.is_valid_url(url):
                url = input("Invalid url, please try again:")
            config["configuration"] = {
                "tp_email": email,
                "tp_url": url,
            }.update(cls.DEFAULT_CONF)

            with open(cls.CONFIG_PATH, "w", encoding="utf8") as config_file:
                config.write(config_file)

        # Read the config file
        if cls.VERBOSE:
            logger.debug("Reading config file at: %s", cls.CONFIG_PATH)
        input_config = configparser.ConfigParser()
        input_config.read(cls.CONFIG_PATH)

        # Version compatibility (#20)
        for config_key, config_value in cls.DEFAULT_CONF.items():
            if not input_config.has_option("configuration", config_key):
                input_config.set("configuration", config_key, config_value)

        with open(cls.CONFIG_PATH, "w", encoding="utf8") as config_file:
            input_config.write(config_file)

        return input_config



""" Setup module for the TP-Timesheet package """
from setuptools import setup
from tp_timesheet import __version__ as version

REQUIREMENTS = [
    "Pillow~=9.2",
    "selenium~=4.4",
    "docker~=6.0",
    "croniter~=1.3",
    "python-crontab~=2.6",
    "workalendar~=16.4.0",
]
DEV_REQUIREMENTS = {
    "dev": [
        "pytest>=6.0.0",
        "pylint~=2.13",
        "black>=22.8",
        "mock~=4.0.3",
    ]
}

with open("README.md", encoding="utf-8") as readme_file:
    LONG_DESCRIPTION = "".join(readme_file.readlines())

setup(
    name="tp-timesheet",
    version=version,
    url="https://github.com/ThorpeJosh/tp-timesheet",
    license="MIT",
    author="Joshua Thorpe",
    author_email="josh@thorpe.engineering",
    description="CLI tool to automate the submisison of tp timesheets",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    keywords=["automation", "timesheet", "cli", "executable"],
    packages=["tp_timesheet"],
    include_package_data=True,
    install_requires=REQUIREMENTS,
    extras_require=DEV_REQUIREMENTS,
    python_requires=">=3.6",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Operating System :: MacOS",
    ],
    entry_points={
        "gui_scripts": ["tp-timesheet=tp_timesheet.__main__:run"],
    },
)
